@@ -1,5 +1,7 @@
 #!/bin/sh
-set -e 
+set -e
+
+retval=0
 
 # for some reason, go.exec.LookPath() fails to obtain the path of iptables
 # on the ci environment, even if $PATH is set correctly.
@@ -16,12 +18,14 @@ if [ -f $log ]; then
     echo "[+] opensnitchd log:"
     cat $log
 fi
-if grep "iptables not available" $log >/dev/null; then
-    echo "[!] iptables not available, falling back to nftables"
-    nft list ruleset | grep "ct state related,new queue flags bypass to 0"
+
+nft list ruleset
+if nft list ruleset | \
+	grep -q "ct state related,new queue flags bypass to 0" ; then
     echo "[+] Interception rule (nftables): OK"
 else
-    /usr/sbin/iptables -t mangle -L OUTPUT
-    /usr/sbin/iptables -t mangle -L OUTPUT | grep "NFQUEUE.*ctstate NEW,RELATED.*NFQUEUE num.*bypass"
-    echo "[+] Interception rule (iptables): OK"
+    echo "[!] Interception rule (nftables): Missing"
+    retval=1
 fi
+
+exit $retval
